@@ -8,7 +8,7 @@ mod.add_function(
             Block([Statement('return "hello world"')])
             ))
 
-from codepy.jit import guess_toolchain
+from codepy.toolchain import guess_toolchain
 cmod = mod.compile(guess_toolchain(), wait_on_error=True)
 
 print cmod.greet()
